grib2io.tables.section1 API documentation

# grib2io.tables.section1

View Source

     1table_1_0 = {
     2'0':'Experimental',
     3'1':'Version Implemented on 7 November 2001',
     4'2':'Version Implemented on 4 November 2003',
     5'3':'Version Implemented on 2 November 2005',
     6'4':'Version Implemented on 7 November 2007',
     7'5':'Version Implemented on 4 November 2009',
     8'6':'Version Implemented on 15 September 2010',
     9'7':'Version Implemented on 4 May 2011',
    10'8':'Version Implemented on 8 November 2011',
    11'9':'Version Implemented on 2 May 2012',
    12'10':'Version Implemented on 7 November 2012',
    13'11':'Version Implemented on 8 May 2013',
    14'12':'Version Implemented on 14 November 2013',
    15'13':'Version Implemented on 7 May 2014',
    16'14':'Version Implemented on 5 November 2014',
    17'16':'Version Implemented on 11 November 2015',
    18'17':'Version Implemented on 4 May 2016',
    19'18':'Version Implemented on 2 November 2016',
    20'19':'Version Implemented on 3 May 2017',
    21'20':'Version Implemented on 8 November 2017',
    22'21':'Version Implemented on 2 May 2018',
    23'22':'Version Implemented on 7 November 2018',
    24'23':'Version Implemented on 15 May 2019',
    25'24':'Version Implemented on 06 November 2019',
    26'25':'Pre-operational to be implemented by next amendment',
    27'26-254':'Future Version',
    28'255':'Missing"',
    29}
    30
    31table_1_1 = {
    32'0':'Local tables not used. Only table entries and templates from the current master table are valid.',
    33'1-254':'Number of local table version used.',
    34'255':'Missing',
    35}
    36
    37table_1_2 = {
    38'0':'Analysis',
    39'1':'Start of Forecast',
    40'2':'Verifying Time of Forecast',
    41'3':'Observation Time',
    42'4':'Local Time',
    43'5-191':'Reserved',
    44'192-254':'Reserved for Local Use',
    45'255':'Missing',
    46}
    47
    48table_1_3 = {
    49'0':'Operational Products',
    50'1':'Operational Test Products',
    51'2':'Research Products',
    52'3':'Re-Analysis Products',
    53'4':'THORPEX Interactive Grand Global Ensemble (TIGGE)',
    54'5':'THORPEX Interactive Grand Global Ensemble (TIGGE) test',
    55'6':'S2S Operational Products',
    56'7':'S2S Test Products',
    57'8':'Uncertainties in ensembles of regional reanalysis project (UERRA)',
    58'9':'Uncertainties in ensembles of regional reanalysis project (UERRA) Test',
    59'10':'Copernicus Regional Reanalysis',
    60'11':'Copernicus Regional Reanalysis Test',
    61'12-191':'Reserved',
    62'192-254':'Reserved for Local Use',
    63'255':'Missing',
    64}
    65
    66table_1_4 = {
    67'0':'Analysis Products',
    68'1':'Forecast Products',
    69'2':'Analysis and Forecast Products',
    70'3':'Control Forecast Products',
    71'4':'Perturbed Forecast Products',
    72'5':'Control and Perturbed Forecast Products',
    73'6':'Processed Satellite Observations',
    74'7':'Processed Radar Observations',
    75'8':'Event Probability',
    76'9-191':'Reserved',
    77'192-254':'Reserved for Local Use',
    78'192':'Experimental Products',
    79'255':'Missing',
    80}
    81
    82table_1_5 = {
    83'0':'Calendar Definition',
    84'1':'Paleontological Offset',
    85'2':'Calendar Definition and Paleontological Offset',
    86'3-32767':'Reserved',
    87'32768-65534':'Reserved for Local Use',
    88'65535':'Missing',
    89}
    90
    91table_1_6 = {
    92'0':'Gregorian',
    93'1':'360-day',
    94'2':'365-day',
    95'3':'Proleptic Gregorian',
    96'4-191':'Reserved',
    97'192-254':'Reserved for Local Use',
    98'255':'Missing',
    99}